agentle.agents.whatsapp.models.whatsapp\_contact
================================================

.. automodule:: agentle.agents.whatsapp.models.whatsapp_contact

   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      WhatsAppContact
   